@@ -1,2 +1,2 @@
-library(meifly)
+# library(meifly)
 lapply(dir("~/documents/meifly/meifly/R", "\\.[Sr]$", full.name=T), source)
